aboutsummaryrefslogtreecommitdiffstats
path: root/src/common.h
diff options
context:
space:
mode:
authorMattias Andrée <m@maandree.se>2025-03-24 16:34:15 +0100
committerMattias Andrée <m@maandree.se>2025-03-24 16:34:15 +0100
commit11f89cf7a9a7375b74a239311e394db3c952fbd9 (patch)
tree8cdd850a991dd9fcac9ad663454750427425edd7 /src/common.h
parentCleanup (diff)
downloadredshift-ng-11f89cf7a9a7375b74a239311e394db3c952fbd9.tar.gz
redshift-ng-11f89cf7a9a7375b74a239311e394db3c952fbd9.tar.bz2
redshift-ng-11f89cf7a9a7375b74a239311e394db3c952fbd9.tar.xz
Add support for specifying hook file
Signed-off-by: Mattias Andrée <m@maandree.se>
Diffstat (limited to 'src/common.h')
-rw-r--r--src/common.h35
1 files changed, 30 insertions, 5 deletions
diff --git a/src/common.h b/src/common.h
index f5be542..61e5c79 100644
--- a/src/common.h
+++ b/src/common.h
@@ -738,6 +738,14 @@ struct setting_time {
};
/**
+ * `char *` valued setting with setting source
+ */
+struct setting_str {
+ enum setting_source source; /**< Setting source */
+ char *value; /**< Setting value */
+};
+
+/**
* Intermediate settings representation of colour settings
* (for a non-transitional period) with settings sources
* used for determining whether settings from the configuration
@@ -807,6 +815,14 @@ struct settings {
int until_death;
/**
+ * The path to the hook file or hook directory, `NULL`
+ * if unspecified (search default paths)
+ *
+ * This represents the "hook" setting and "-H" option
+ */
+ struct setting_str hook_file;
+
+ /**
* Whether the program should preserve preapplied
* colour calibrations
*
@@ -1183,6 +1199,12 @@ extern int use_fade;
*/
extern int verbose;
+/**
+ * The path to the hook file or hook directory, `NULL`
+ * if unspecified (search default paths)
+ */
+extern char *hook_file;
+
/* backend-direct.c */
@@ -1357,11 +1379,14 @@ LIST_RAMPS_STOP_VALUE_TYPES(X, ;);
/**
* Load the configuration file
*
- * @param state Output parameter for the configurations
- * @param path The path to the configuration file, or `NULL` if the
- * application should look for it in the default paths
- */
-void config_ini_init(struct config_ini_state *state, const char *path);
+ * @param state Output parameter for the configurations
+ * @param path The path to the configuration file, or `NULL` if the
+ * application should look for it in the default paths
+ * @param pathbuf_out Output parameter for the memory allocated for the
+ * return value
+ * @return The path to the loaded configuration file, `NULL` if none
+ */
+const char *config_ini_init(struct config_ini_state *state, const char *path, char **pathbuf_out);
/**
* Deallocate the settings loaded